package com.yardpros;

import java.util.*;

/**
 *This class holds products for purchase at yardpros.
 *Note that the productID and amount are set off by puting ints in, otherwise
 * ther 
 *method.
*/
public class Cart extends LinkedHashMap
{
  public static final int QUANTITY = 0;
  public static final int PRICE = 1;
  
  private String creditCard;
  private String creditCardNumber;
  private String expirationDate;
  private String confirmNumber;
  
  /**
   *Starts with an empty cart
  */
  public Cart()
  {
    clear();
  }
   /**
   *This method puts a product and an amount in the cart
   *@param (int)productID - the product to add
   *@param (int)quantity - the quantity to add
   */
   public Object put(int productID, int quantity)
   {
     //adds more of the item to the cart
     if(get(productID) != null)
       quantity = ((Integer)get(productID)).intValue()+quantity;
       
     return super.put(productID, quantity);
   }
   
  /**
   *Returns a string with all the info about the cart
   *@return String - a string representation of everything in the cart
   */
  public String toString()
  {
    String temp = super.toString()+
           ",creditcard = "+getCreditCard()+
           ",creditcardnumber = "+getCreditCardNumber()+
           ",expirationdate = "+getExpirationDate()+
           ",confirmnumber = "+getConfirmNumber();
     
    return temp;
  }
   
  /**
  * Checks the bean to see that all of the values are valid entries for the
  * database
  */
  public void checkEntries()
         throws InvalidInputException
  {
    
    //checks for negative  numbers
    for(int i: (java.util.Set<Integer>)keySet())
      if( ((Integer)get(i)).intValue()<=0 )
        throw new InvalidInputException("Nice Try, Jack");
      
  }
  
  /**
   * This is makes sure that all of the checkout information is ok
   * @throws InvalidInputException - if somehthing doesnt check out.
   */
  public void checkout() throws InvalidInputException
  {
    //checks to see that the credit card number is a number
    try
    {
      Long.parseLong(getCreditCardNumber());
    }
    catch(NumberFormatException e)
    {
      System.out.println("Why the f is this happening");
      throw new InvalidInputException("You entered an non-number Credit Card Number: "+
                                      getCreditCardNumber());
    }
    
    //checks to see that the Credit Card number is the correct length
    if(getCreditCardNumber().length() != 16 )
      throw new InvalidInputException("Your Credit card number was only "+
                                getCreditCardNumber().length()+" digits long ");
    
    //checks to see that the confirmation number is a number
    try
    {
      Integer.parseInt(getConfirmNumber());
    }
    catch(Exception e)
    {
      throw new InvalidInputException("You entered an invalid Confirmation Number");
    }
  }
    
    /**
     *Clears the cart
     */
    public void clear()
    {
      super.clear();
      setCreditCard("");
      setCreditCardNumber("");
      setExpirationDate("");
      setConfirmNumber("");
    }  
    
    
/**********             HashMap with an object [] of metainfo           *****
/********** would be nice to implement but having troubles with casting *****
 *This method puts a product and an amount in the cart
 *@param (int)productID - the product to add
 *@param (Object[])metaData - the quantity to add in index QUANTITY
 *                         and the price in index PRICE
 *
 public Object put(int productID, Object[] metaData)
 {
   int quantity = ((Integer)metaData[QUANTITY]).intValue();
   double price = ((Double)metaData[PRICE]).doubleValue();
   //adds more of the item to the cart
   if(get(productID) != null)
   {
     quantity = (Integer)( (Object[])(get(productID))[QUANTITY] ).intValue()+quantity;
     price = quantity * price;
   }
     
   return super.put(productID, quantity);
 }
*****************************************************************************/

    
/***************** get and set methods **********************/    
  /**
	 * Returns the value of creditCard.
	 */
	public String getCreditCard()
	{
		return creditCard;
	}

	/**
	 * Sets the value of creditCard.
	 * @param creditCard The value to assign creditCard.
	 */
	public void setCreditCard(String creditCard)
	{
		this.creditCard = creditCard;
	}

	/**
	 * Returns the value of creditCardNumber.
	 */
	public String getCreditCardNumber()
	{
		return creditCardNumber;
	}

	/**
	 * Sets the value of creditCardNumber.
	 * @param creditCardNumber The value to assign creditCardNumber.
	 */
	public void setCreditCardNumber(String creditCardNumber)
	{
		this.creditCardNumber = creditCardNumber;
	}

	/**
	 * Returns the value of expirationDate.
	 */
	public String getExpirationDate()
	{
		return expirationDate;
	}

	/**
	 * Sets the value of expirationDate.
	 * @param expirationDate The value to assign expirationDate.
	 */
	public void setExpirationDate(String expirationDate)
	{
		this.expirationDate = expirationDate;
	}

	/**
	 * Returns the value of confirmNumber.
	 */
	public String getConfirmNumber()
	{
		return confirmNumber;
	}

	/**
	 * Sets the value of confirmNumber.
	 * @param confirmNumber The value to assign confirmNumber.
	 */
	public void setConfirmNumber(String confirmNumber)
	{
		this.confirmNumber = confirmNumber;
	}
}
